@@ -1,21 +1,39 @@
-package MBX::FLTK;
+package inc::MBX::FLTK;
 {
     use strict;
     use warnings;
     $|++;
     use Config qw[%Config];
     use ExtUtils::ParseXS qw[];
-    use ExtUtils::CBuilder qw[];
     use File::Spec::Functions qw[catdir rel2abs abs2rel canonpath];
     use File::Find qw[find];
     use File::Path qw[make_path];
     use base 'Module::Build';
+    {
+
+        package My::ExtUtils::CBuilder;
+        use base 'ExtUtils::CBuilder';
+
+        sub do_system {
+            my ($self, @cmd) = @_;
+            @cmd = grep { defined && length } @cmd;
+            @cmd = map { s[\s+$][]; s[^\s+][]; $_ } @cmd;
+            print "@cmd\n" if !$self->{'quiet'};
+            my $cmd = join ' ', @cmd;
+            `$cmd`;
+            return 1;
+
+            #(my( $program), @cmd) = @cmd;
+            #return !system ($program, @cmd);
+        }
+    }
     {
 
         sub ACTION_code {
-            require Alien::FLTK;    # Should be installed by now
+            require Alien::FLTK2;    # Should be installed by now
             my ($self, $args) = @_;
-            my $AF = Alien::FLTK->new();
+            my $AF = Alien::FLTK2->new();
+            my $CC = My::ExtUtils::CBuilder->new();
             my (@xs, @rc, @obj);
             find(sub { push @xs, $File::Find::name if m[.+\.xs$]; }, 'xs');
             find(sub { push @rc, $File::Find::name if !m[.+\.o$]; }, 'xs/rc');
@@ -32,29 +50,26 @@ package MBX::FLTK;
                     chdir 'xs/rc';
                     print $self->do_system(sprintf 'windres %s %s',
                                       $dot_rc, $dot_o) ? "okay\n" : "fail!\n";
-                    chdir $self->base_dir;
+                    chdir rel2abs($self->base_dir);
                 }
                 map { abs2rel($_) } @obj;
             }
         XS: for my $XS (@xs) {
                 my $cpp = _xs_to_cpp($self, $XS)
                     or do { printf 'Cannot Parse %s', $XS; exit 0 };
-                if ($self->up_to_date($cpp, $self->cbuilder->object_file($cpp)
-                    )
-                    )
-                {   push @obj, $self->cbuilder->object_file($cpp);
+                if ($self->up_to_date($cpp, $CC->object_file($cpp))) {
+                    push @obj, $CC->object_file($cpp);
                     next XS;
                 }
                 push @obj,
-                    $self->cbuilder->compile(
-                                       'C++'        => 1,
-                                       source       => $cpp,
-                                       include_dirs => [$AF->include_dirs()],
-                                       extra_compiler_flags => $AF->cxxflags()
+                    $CC->compile('C++'        => 1,
+                                 source       => $cpp,
+                                 include_dirs => [$AF->include_dirs()],
+                                 extra_compiler_flags => [$AF->cxxflags()]
                     );
             }
             make_path(catdir(qw[blib arch auto FLTK]),
-                      {verbose => !$self->quiet(), mode => 0711});
+                      {verbose => !$self->quiet(), mode => 0777});
             @obj = map { canonpath abs2rel($_) } @obj;
             if (!$self->up_to_date([@obj],
                                    catdir(qw[blib arch auto FLTK],
@@ -63,14 +78,14 @@ package MBX::FLTK;
                 )
                 )
             {   my ($dll, @cleanup)
-                    = $self->cbuilder->link(
-                            objects => \@obj,
-                            lib_file =>
-                                catdir(qw[blib arch auto FLTK],
-                                       'FLTK.' . $Config{'so'}
-                                ),
-                            module_name        => 'FLTK',
-                            extra_linker_flags => $AF->ldflags(qw[gl images]),
+                    = $CC->link(
+                          objects => \@obj,
+                          lib_file =>
+                              catdir(qw[blib arch auto FLTK],
+                                     'FLTK.' . $Config{'so'}
+                              ),
+                          module_name        => 'FLTK',
+                          extra_linker_flags => [$AF->ldflags(qw[gl images])],
                     );
                 @cleanup = map { s["][]g; rel2abs($_); } @cleanup;
                 $self->add_to_cleanup(@cleanup);
@@ -123,7 +138,6 @@ package MBX::FLTK;
         }
         use File::Path qw[make_path];
         use File::Spec::Functions qw[splitpath];
-        my %modules;
         {
 
             package Pod::APIDoc::FLTK;
@@ -137,11 +151,13 @@ package MBX::FLTK;
                 my ($self, $command, $paragraph, $lineno) = @_;
                 if ($command eq 'head1') {
                     $paragraph =~ s|\s+$||;
-                    $current = \$modules{$package}{'section'}{$paragraph};
+                    $current = \$self->{'apidoc_modules'}{$package}{'section'}
+                        {$paragraph};
                     $$current = {line => $lineno,
                                  file => $self->input_file
                     };
-                    push @{$modules{$package}{'@section'}}, $paragraph;
+                    push @{$self->{'apidoc_modules'}{$package}{'@section'}},
+                        $paragraph;
                     return;
                 }
                 elsif ($command eq 'for') {
@@ -152,8 +168,13 @@ package MBX::FLTK;
                         warn sprintf 'Malformed apidoc at %s line %d',
                             $self->input_file, $lineno
                             if !$sub;
-                        $current = \$modules{$package}{$type}{$sub}
-                            ->[scalar @{$modules{$package}{$type}{$sub}}];
+                        $current
+                            = \$self->{'apidoc_modules'}{$package}{$type}
+                            {$sub}->[
+                            scalar
+                            @{$self->{'apidoc_modules'}{$package}{$type}
+                                    {$sub}}
+                            ];
                         $$current = {flags  => $flags,
                                      prereq => $prereq,
                                      return => $return,
@@ -165,7 +186,7 @@ package MBX::FLTK;
                     }
                     elsif (
                          $paragraph =~ m[(license|author|version|git)\s+(.+)])
-                    {   $modules{$package}{'.'}{$1}{$2}++;
+                    {   $self->{'apidoc_modules'}{$package}{'.'}{$1}{$2}++;
                         return;
                     }
                 }
@@ -222,7 +243,7 @@ package MBX::FLTK;
             print 'Parsing XS files for documentation... ';
             $parser->parse_from_file('xs/FLTK.xs');
             print "okay\nGenerating documentation... ";
-            for my $package (sort keys %modules) {
+            for my $package (sort keys %{$parser->{'apidoc_modules'}}) {
                 my $file = './blib/lib/' . $package . '.pod';
                 $file =~ s|::|/|g;
                 make_path((splitpath($file))[0 .. 1]);
@@ -231,35 +252,47 @@ package MBX::FLTK;
                 syswrite $DOC, "=pod\n\n";
                 {
                     for my $section (qw[NAME Description Synopsis]) {
-                        next if !$modules{$package}{'section'}{$section};
+                        next
+                            if !$parser->{'apidoc_modules'}{$package}
+                            {'section'}{$section};
                         syswrite $DOC, "=head1 $section\n\n";
                         syswrite $DOC,
-                            $modules{$package}{'section'}{$section}{'text'};
+                            $parser->{'apidoc_modules'}{$package}{'section'}
+                            {$section}{'text'};
                     }
-                    if (keys %{$modules{$package}{'sub'}}) {
-                        syswrite $DOC, "=head1 Functions\n\n";
-                        for my $sub (sort keys %{$modules{$package}{'sub'}}) {
-                            syswrite $DOC, "=head2 C<$sub>\nX<$sub>\n\n";
+                    if (keys %{$parser->{'apidoc_modules'}{$package}{'sub'}})
+                    {   syswrite $DOC, "=head1 Functions\n\n";
+                        for my $sub (
+                              sort keys
+                              %{$parser->{'apidoc_modules'}{$package}{'sub'}})
+                        {   syswrite $DOC, "=head2 C<$sub>\nX<$sub>\n\n";
                             syswrite $DOC, "=over\n\n";
-                            for my $use (0 ..
-                                    scalar(@{$modules{$package}{'sub'}{$sub}})
-                                    - 1)
+                            for my $use (
+                                 0 .. scalar(
+                                     @{  $parser->{'apidoc_modules'}{$package}
+                                             {'sub'}{$sub}
+                                         }
+                                 ) - 1
+                                )
                             {   my $call
-                                    = $self->_document_function($package,
-                                       $sub,
-                                       $modules{$package}{'sub'}{$sub}[$use]);
+                                    = $self->_document_function(
+                                         $package,
+                                         $sub,
+                                         $parser->{'apidoc_modules'}{$package}
+                                             {'sub'}{$sub}[$use]
+                                    );
                                 my $_call = $call;
                                 $_call =~ s|[^\w]+|_|g;
                                 syswrite $DOC, "=item C<$call>X<$_call>\n\n";
                                 syswrite $DOC,
-                                    ($modules{$package}{'sub'}{$sub}[$use]
-                                     {'text'} || '');
+                                    ($parser->{'apidoc_modules'}{$package}
+                                     {'sub'}{$sub}[$use]{'text'} || '');
                                 syswrite $DOC,
                                     sprintf "=for hackers %s line %d\n\n",
-                                    $modules{$package}{'sub'}{$sub}[$use]
-                                    {'file'},
-                                    $modules{$package}{'sub'}{$sub}[$use]
-                                    {'line'};
+                                    $parser->{'apidoc_modules'}{$package}
+                                    {'sub'}{$sub}[$use]{'file'},
+                                    $parser->{'apidoc_modules'}{$package}
+                                    {'sub'}{$sub}[$use]{'line'};
                             }
                             syswrite $DOC, "=back\n\n";
                         }
@@ -267,19 +300,29 @@ package MBX::FLTK;
                     for my $section (
                         grep {
                             !m[(?:NAME|Description|Synopsis)]
-                        } @{$modules{$package}{'@section'}}
+                        } @{$parser->{'apidoc_modules'}{$package}{'@section'}}
                         )
-                    {   next if !$modules{$package}{'section'}{$section};
+                    {   next
+                            if !$parser->{'apidoc_modules'}{$package}
+                            {'section'}{$section};
                         syswrite $DOC, "=head1 $section\n\n";
                         syswrite $DOC,
-                            $modules{$package}{'section'}{$section}{'text'};
+                            $parser->{'apidoc_modules'}{$package}{'section'}
+                            {$section}{'text'} || '';
                     }
                     {
-                        if (scalar keys %{$modules{$package}{'.'}{'author'}})
+                        if (scalar keys %{
+                                $parser->{'apidoc_modules'}{$package}{'.'}
+                                    {'author'}
+                            }
+                            )
                         {   syswrite $DOC, "=head1 Author\n\n";
                             for my $author (
-                                     sort
-                                     keys %{$modules{$package}{'.'}{'author'}}
+                                sort
+                                keys %{
+                                    $parser->{'apidoc_modules'}{$package}{'.'}
+                                        {'author'}
+                                }
                                 )
                             {   syswrite $DOC, "$author\n\n";
                             }
@@ -287,8 +330,11 @@ package MBX::FLTK;
                         else {
                             syswrite $DOC, "=head1 Authors\n\n=over\n\n";
                             for my $author (
-                                     sort
-                                     keys %{$modules{$package}{'.'}{'author'}}
+                                sort
+                                keys %{
+                                    $parser->{'apidoc_modules'}{$package}{'.'}
+                                        {'author'}
+                                }
                                 )
                             {   syswrite $DOC, "=item $author\n\n";
                             }
@@ -297,15 +343,14 @@ package MBX::FLTK;
                     }
                     syswrite $DOC, "=head1 License and Legal\n\n";
                     syswrite $DOC, $self->LICENSE() . "\n\n";
-                    for my $id (sort keys %{$modules{$package}{'.'}{'git'}}) {
-                        syswrite $DOC, "=for git $id\n\n";
+                    for my $id (
+                         sort keys
+                         %{$parser->{'apidoc_modules'}{$package}{'.'}{'git'}})
+                    {   syswrite $DOC, "=for git $id\n\n";
                     }
                 }
                 syswrite $DOC, "=cut\n";
                 close $DOC;
-
-                #dd $modules{$package};
-                #die;
             }
             print "okay\n";
         }
@@ -372,15 +417,15 @@ package MBX::FLTK;
 
 =pod
 
-=for $Rev: c9b696e $
+=for $Rev: 7aee1fa $
 
-=for $Revision: c9b696ef5a2b09285cba3bbf0fb3f91cd4692b24 $
+=for $Revision: 7aee1fa6f73b4e2bfb8a9a5e8470ec4c0aba114f $
 
-=for $Date: 2009-11-05 18:41:28Z (Thu, 05 Nov 2009) $ | Last $Modified: 3 days ago $
+=for $Date: 2010-04-12 14:30:14Z (Mon, 12 Apr 2010) $ | Last $Modified: 5 days ago $
 
-=for $URL: http://github.com/sanko/fltk-perl/raw/master/inc/MBX/FLTK.pm $
+=for $URL: http://github.com/sanko/perl-fltk2/raw/master/inc/MBX/FLTK.pm $
 
-=for $ID: FLTK.pm c9b696e 2009-11-05 18:41:28Z sanko@cpan.org $
+=for $ID: FLTK.pm 7aee1fa 2010-04-12 14:30:14Z sanko@cpan.org $
 
 =for author Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
 
