@@ -13,9 +13,9 @@
 
 =for seealso xs/GlWindow.xsi
 
-=for seealso xs/include/RectangleSubclass.h
+=for seealso xs/include/WidgetSubclass.h
 
-=for git $Id: GlWindowSubclass.h 7483df2 2011-04-09 05:42:22Z sanko@cpan.org $
+=for git $Id: GlWindowSubclass.h 4240aaf 2009-09-24 21:42:29Z sanko@cpan.org $
 
 =cut
 
@@ -25,17 +25,17 @@
 #include <fltk/GlWindow.h> // Minimum.
 #endif
 
-#ifndef fltk_RectangleSubclass_h
-#include <include/RectangleSubclass.h>
+#ifndef fltk_WidgetSubclass_h
+#include <include/WidgetSubclass.h>
 #endif
 
 template<>
-void RectangleSubclass<fltk::GlWindow>::draw ( ) {
-	int handled = 1; /* safe to assume for now */
-	dTHX;
-	AV * args = newAV();
-	handled = _call_method( "draw", args );
-	/* GlWindow::draw( ) is a pure virtual function */
+void WidgetSubclass<fltk::GlWindow>::draw ( ) {
+    int handled = 1; /* safe to assume for now */
+    dTHX;
+    AV * args = newAV();
+    handled = _call_method( "draw", args );
+    /* GlWindow::draw( ) is a pure virtual function */
 }
 
 #endif // #ifndef fltk_GlWindowSubclass_h
